<div align="center">
    <img src="../../docs/images/logo-title.png" height="80px">
    <h3>The Graph Of LIfe Library.</h3>
</div>


## What is in this folder? 

folder for utils and helper functions

- ✅ `spaces.py`: the file to track the space of all names and dictionaries
- `mup.py`: helper function for mup operations
